==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebSplitPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebSplitPaneDescription } from "./WebSplitPaneDescription";
/**
 * @hidden
 */
export let WebSplitPaneDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSplitPaneDescriptionMetadata extends Base {
        static b(a) {
            if (WebSplitPaneDescriptionMetadata.a == null) {
                WebSplitPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSplitPaneDescriptionMetadata.c(WebSplitPaneDescriptionMetadata.a);
            }
            if (a.j(WebSplitPaneDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSplitPaneDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebDockManagerPaneDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:SplitPane");
            a.item("Id", "String");
            a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
            a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
            a.item("Orientation", "ExportedType:string:SplitPaneOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("Panes", "Collection:WebDockManagerPane:DockManagerPaneCollection:WebDockManagerPane");
            a.item("Size", "Number:double");
            a.item("FloatingLocation", "ExportedType:WebDockManagerPoint");
            a.item("FloatingWidth", "Number:double");
            a.item("FloatingHeight", "Number:double");
            a.item("FloatingResizable", "Boolean");
            a.item("AllowEmpty", "Boolean");
        }
        static d(a) {
            WebSplitPaneDescriptionMetadata.b(a);
            a.aa("WebSplitPane", () => new WebSplitPaneDescription());
            a.z("WebSplitPane", WebSplitPaneDescriptionMetadata.a);
        }
    }
    WebSplitPaneDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSplitPaneDescriptionMetadata, 'WebSplitPaneDescriptionMetadata');
    WebSplitPaneDescriptionMetadata.a = null;
    return WebSplitPaneDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebSplitPaneDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebDockManagerPaneDescriptionMetadata } from "./WebDockManagerPaneDescriptionMetadata";
import { WebSplitPaneDescription } from "./WebSplitPaneDescription";
/**
 * @hidden
 */
export let WebSplitPaneDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSplitPaneDescriptionMetadata extends Base {
        static b(a) {
            if (WebSplitPaneDescriptionMetadata.a == null) {
                WebSplitPaneDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSplitPaneDescriptionMetadata.c(WebSplitPaneDescriptionMetadata.a);
            }
            if (a.k(WebSplitPaneDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSplitPaneDescriptionMetadata.a);
            WebDockManagerPointDescriptionMetadata.d(a);
        }
        static c(a) {
            WebDockManagerPaneDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:SplitPane");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Id", "String");
            a.item("PaneType", "(wc:Type)ExportedType:string:DockManagerPaneType");
            a.item("PaneType@names", "SplitPane;ContentPane;TabGroupPane;DocumentHost");
            a.item("Orientation", "ExportedType:string:SplitPaneOrientation");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("Panes", "Collection:WebDockManagerPane:DockManagerPaneCollection:WebDockManagerPane");
            a.item("Size", "Number:double");
            a.item("FloatingLocation", "ExportedType:WebDockManagerPoint");
            a.item("FloatingWidth", "Number:double");
            a.item("FloatingHeight", "Number:double");
            a.item("FloatingResizable", "Boolean");
            a.item("AllowEmpty", "Boolean");
        }
        static d(a) {
            WebSplitPaneDescriptionMetadata.b(a);
            a.ac("WebSplitPane", () => new WebSplitPaneDescription());
            a.ab("WebSplitPane", WebSplitPaneDescriptionMetadata.a);
        }
    }
    WebSplitPaneDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSplitPaneDescriptionMetadata, 'WebSplitPaneDescriptionMetadata');
    WebSplitPaneDescriptionMetadata.a = null;
    return WebSplitPaneDescriptionMetadata;
})();
